# ---------------------------------------------------------------------------
# LandscapeStats.py
# Created on: Mon Nov 01 2010 06:17:22 PM
# Created by: Erin Poor, GIS Analyst, WWF-US
#               erin.poor@wwfus.org
# Description:
# This tool calculates the area of All Habitat, Suitable Habitat, Degraded Habitat and Poor Habitat from a habitat suitablility model. Thresholds of habitat quality types may be changed according to the requirements of the focal species.
# ---------------------------------------------------------------------------

# Import system modules
import sys, string, os, arcgisscripting

# Create the Geoprocessor object
gp = arcgisscripting.create()
gp.overwriteoutput = 1

# Check out any necessary licenses
gp.CheckOutExtension("spatial")
Suitability_Layer = gp.GetParameterAsText(1)

# Set the Geoprocessing environment...
inworkspace = gp.GetParameterAsText(0)
outworkspace = gp.GetParameterAsText(0)
gp.workspace = inworkspace
gp.snapRaster = Suitability_Layer
gp.extent = Suitability_Layer
gp.mask = Suitability_Layer

# Script arguments...
Good = gp.GetParameterAsText(2)
Bad = gp.GetParameterAsText(3)
all_hab4 = gp.GetParameterAsText(4)
msgArguments = "\nProblem with arguments."

# Local variables...
good_hab = "good_hab"
Input_true1 = "1"
Input_false1 = "0"
all_hab1 = "all_hab1"

all_habpoly = "all_habpoly.shp"
poor_hab = "poor_hab"
Input_true2 = "3"
Input_false2 = "good_hab"
all_hab2 = "all_hab2"

all_habpoly1 = "all_habpoly1.shp"
all_habpoly2 = "all_habpoly2.shp"
all_habpoly3 = "all_habpoly3.shp"
Input_true3 = "2"
Input_false3 = "poor_hab"

all_hab = "all_hab"
hab = "hab.shp"
hab2 = "hab2.shp"

def checkCellSize(thedata):
        desc=gp.Describe(thedata)
        CellWidth = desc.MeanCellWidth
        CellHeight = desc.MeanCellHeight
        return int((CellHeight+CellWidth)/2.0)

S_cellsize = checkCellSize(Suitability_Layer)
gp.cellsize = S_cellsize

#################################### GOOD HABITAT ########################################
try:
    gp.AddMessage ("Step 1 of 10: Calculating suitable habitat")
    gp.Con_sa(Suitability_Layer, Input_true1, good_hab, Input_false1, "Value >= "+Good+"")
except:
    raise Exception, msgArguments + gp.GetMessages(2)
        
######################################## BAD HABITAT #####################################
try:
    gp.AddMessage ("Step 2 of 10: Calculating poor habitat")
    gp.Con_sa(Suitability_Layer, Input_true2, poor_hab, Input_false2, "Value < "+Bad+"")
except:
    raise Exception, msgArguments + gp.GetMessages(2)
        
################################### INTERMEDIATE HABITAT #################################          
try:
    gp.AddMessage ("Step 3 of 10: Calculating moderate habitat")
    gp.Con_sa(poor_hab, Input_true3, all_hab, Input_false3, "Value = 0")
except:
    raise Exception, msgArguments + gp.GetMessages(2)
    
########################################## AREA ##########################################
try:
    gp.AddMessage ("Step 4 of 10: Converting to shapes")
    gp.RasterToPolygon_conversion(all_hab, all_habpoly, "", "VALUE")

    gp.AddMessage ("Step 5 of 10: Labeling 'good'")
    gp.select_analysis(all_habpoly, all_habpoly1, "GRIDCODE = 1")
    gp.AddField_management(all_habpoly1, "Type", "TEXT", "", "", "", "", "NON_NULLABLE", "NON_REQUIRED", "")
    gp.CalculateField_management(all_habpoly1, "Type", "'Good'", "PYTHON", "")

    gp.AddMessage("Step 6 of 10: Labeling 'moderate'")
    gp.select_analysis(all_habpoly, all_habpoly2, "GRIDCODE = 2")
    gp.AddField_management(all_habpoly2, "Type", "TEXT", "", "", "", "", "NON_NULLABLE", "NON_REQUIRED", "")
    gp.CalculateField_management(all_habpoly2, "Type", "'Moderate'", "PYTHON", "")

    gp.AddMessage("Step 7 of 10: Labeling 'poor'")
    gp.select_analysis(all_habpoly, all_habpoly3, "GRIDCODE = 3")
    gp.AddField_management(all_habpoly3, "Type", "TEXT", "", "", "", "", "NON_NULLABLE", "NON_REQUIRED", "")
    gp.CalculateField_management(all_habpoly3, "Type", "'Poor'", "PYTHON", "")

    gp.AddMessage("Step 8 of 10: Merging labeled files together")
    gp.Append_management("all_habpoly2.shp; all_habpoly3.shp", "all_habpoly1.shp", "NO_TEST")
    gp.AddMessage ("Step 9 of 10: Converting to raster")
    gp.PolygonToRaster("all_habpoly1.shp", "Type", all_hab4, "", "", str(S_cellsize))

    gp.AddMessage ("Step 10 of 10: Calculating areas")
    gp.AddField_management(all_hab4, "Area", "Float", "", "", "", "", "NON_NULLABLE", "NON_REQUIRED", "")
    gp.CalculateField_management(all_hab4, "Area", "([COUNT] * "+str(S_cellsize)+" * "+str(S_cellsize)+") / 1000.0", "VB", "")

except:
    raise Exception, msgArguments + gp.GetMessages(2)

########################################## DELETE ##########################################
    
gp.delete_management("good_hab")
gp.delete_management("poor_hab")
gp.delete_management("all_hab")
gp.delete_management("all_habpoly.shp")
gp.delete_management("all_habpoly1.shp")
gp.delete_management("all_habpoly2.shp")
gp.delete_management("all_habpoly3.shp")

gp.AddMessage ("Landscape Statistics have been calculated for your landscape!")
