# ---------------------------------------------------------------------------
# PatchDistance.py
# Created on: Thu Apr 14 2010 
# Created by: Erin Poor, GIS Analyst, WWF-US
#               erin.poor@wwfus.org
# Usage: PatchDistance
# Description: 
# 
# ---------------------------------------------------------------------------

# Import system modules
import sys, string, os, arcgisscripting


# Create the Geoprocessor object
gp = arcgisscripting.create()
gp.OverWriteOutput = 1

# Check out any necessary licenses
gp.CheckOutExtension("spatial")

# Set the Geoprocessing environment...
inworkspace = gp.GetParameterAsText(0)
outworkspace = gp.GetParameterAsText(0)
gp.workspace = inworkspace

# Script arguments...
Patches = gp.GetParameterAsText(1)
Size = gp.GetParameterAsText(2)
Input = gp.GetParameterAsText(3)
ConnectedHabitat = gp.GetParameterAsText(4)
gp.cellsize = gp.GetParameterAsText(5)
delete = gp.GetParameterAsText(6).upper()
msgArguments = "\nProblem with arguments."

# Local variables...
Cores = "Cores.shp"
NonCore = "NonCore.shp"
SelectPatches = "SelectPatches.shp"
patchdist = "patchdist"
groups = "groups"
regions = "regions"
Regionspoly = "Regionspoly.shp"
PatchGroups = "PatchGroups.shp"
All = "All.shp"
trial = "trial.shp"

##Running Near tool for core patches
gp.AddMessage("Step 1 of 6: Identifying cores and non-core patches")
gp.Select_analysis(Patches, Cores, " \"Type\" = 'Core' ")
gp.Select_analysis(Patches, NonCore, " \"Type\" = 'Patch' ")
    
if int(gp.GetCount_management(Cores)) is not 0:
    if Size:
        gp.AddMessage("Step 2 of 6: Identifying cores closest to other cores")
        gp.Near_analysis("Cores.shp","Cores.shp","#","NO_LOCATION","NO_ANGLE")

        gp.AddMessage("Step 3 of 6: Updating core patch attribute table")

        ## Calculating distance in kilometers and deleting default Near column
        gp.AddField_management(Cores, "NearDist","DOUBLE","#","#","#","#","NON_NULLABLE","NON_REQUIRED","#")
        gp.CalculateField_management(Cores, "NearDist", "!NEAR_DIST! /1000", "PYTHON", "#")
        gp.DeleteField_management(Cores, "NEAR_DIST")

        ## Calculating CoreID column and deleting default Near ID column
        gp.AddField_management(Cores, "CoreID", "LONG", "#", "#", "#", "#", "NON_NULLABLE", "NON_REQUIRED", "#")
        gp.CalculateField_management(Cores, "CoreID", "!FID! + 1", "PYTHON", "#")
        gp.DeleteField_management(Cores, "NEAR_FID")

        gp.AddMessage("Step 4 of 6: Identifying cores closest to non-core patches")
        gp.Select_analysis(NonCore, "SelectPatches.shp", "Area >= "+Size+"")
        gp.Near_analysis("SelectPatches.shp", Cores)

        gp.AddMessage("Step 5 of 6: Updating non-core patch attribute table")
        # Calculating distance in kilometers and deleting default Near column
        gp.AddField_management("SelectPatches.shp", "NearDist","DOUBLE","#","#","#","#","NON_NULLABLE","NON_REQUIRED","#")
        gp.CalculateField_management("SelectPatches.shp", "NearDist", "!NEAR_DIST! /1000", "PYTHON", "#")
        gp.DeleteField_management("SelectPatches.shp", "NEAR_DIST")

        # Calculating CoreID column and deleting default Near ID column
        gp.AddField_management("SelectPatches.shp", "CoreID", "LONG", "#", "#", "#", "#", "NON_NULLABLE", "NON_REQUIRED", "#")
        gp.CalculateField_management("SelectPatches.shp", "CoreID", "!NEAR_FID! + 1", "PYTHON", "#")
        gp.DeleteField_management("SelectPatches.shp", "NEAR_FID")
        
        gp.AddMessage("Step 6 of 6: Identifying networks of patches that are functionally connected")
        gp.Merge_management("Cores.shp;SelectPatches.shp", "All.shp", "#")
        gp.EucDistance_sa("All.shp", "patchdist")
        gp.Con_sa("patchdist", 1, groups, "", "Value <= "+str(float(Input)/2.0)) 
        gp.RegionGroup_sa(groups, regions, "EIGHT", "WITHIN","ADD_LINK","#")
        gp.RasterToPolygon_conversion(regions, "regionspoly.shp", "SIMPLIFY")
        gp.SpatialJoin_analysis("All.shp", "regionspoly.shp", "trial.shp", "JOIN_ONE_TO_ONE", "KEEP_COMMON")
        gp.Copy_management("trial.shp", ConnectedHabitat)
        gp.AddField_management(ConnectedHabitat, "RegionID", "DOUBLE", "#", "#", "#", "#", "NON_NULLABLE", "NON_REQUIRED", "#")
        gp.CalculateField_management(ConnectedHabitat, "RegionID", "!GRIDCODE_1!", "PYTHON", "#")
      
    else: 
        gp.AddMessage("Step 2 of 6: Identifying networks of patches that are functionally connected")
        gp.Merge_management("Cores.shp;NonCore.shp", "All.shp", "#")
        gp.EucDistance_sa("All.shp", "patchdist")
        gp.Con_sa("patchdist", 1, groups, "", "Value <= "+str(float(Input)/2.0))
        gp.RegionGroup_sa(groups, regions, "EIGHT", "WITHIN","ADD_LINK","#")
        gp.RasterToPolygon_conversion(regions, "regionspoly.shp", "SIMPLIFY")
        gp.SpatialJoin_analysis("All.shp", "regionspoly.shp", "trial.shp", "JOIN_ONE_TO_ONE", "KEEP_COMMON")
        gp.Copy_management("trial.shp", ConnectedHabitat)
        gp.AddField_management(ConnectedHabitat, "RegionID", "DOUBLE", "#", "#", "#", "#", "NON_NULLABLE", "NON_REQUIRED", "#")
        gp.CalculateField_management(ConnectedHabitat, "RegionID", "!GRIDCODE_1!", "PYTHON", "#")
        gp.AddMessage("   No size selected, skipping Steps 3-6")
        
    gp.DeleteField_management(ConnectedHabitat, "Shape_Length")
    gp.DeleteField_management(ConnectedHabitat, "Shape_Area")
    gp.DeleteField_management(ConnectedHabitat, "Join_Count")
    gp.DeleteField_management(ConnectedHabitat, "TARGET_FID")
    gp.DeleteField_management(ConnectedHabitat, "INTERSECT")
    gp.DeleteField_management(ConnectedHabitat, "ID")
    gp.DeleteField_management(ConnectedHabitat, "ID_1")
    gp.DeleteField_management(ConnectedHabitat, "JOIN_FID")
    gp.DeleteField_management(ConnectedHabitat, "GRIDCODE_1")

    if delete in ["TRUE", True]:
        gp.AddMessage("Deleting intermediate data")

        if Size:
            gp.delete_management("SelectPatches.shp")

        gp.delete_management("All.shp")
        gp.delete_management("PatchDist")
        gp.delete_management("groups")
        gp.delete_management("regions")
        gp.delete_management("regionspoly.shp")
        gp.delete_management("trial.shp")
        gp.AddMessage("Tool has completed!")
    else:
        gp.AddMessage("Tool has completed!")
        
###########################################################################################################################
####################################### IF THERE ARE NO CORES... ##########################################################
###########################################################################################################################
        
if int(gp.GetCount_management(Cores))== 0:
    if Size:
        gp.AddMessage("Step 2 of 6: Identifying non-cores closest to other non-core patches")
        gp.Select_analysis(NonCore, SelectPatches, "Area >= "+Size+"")
        gp.Near_analysis(SelectPatches, SelectPatches)

        gp.AddMessage("Step 3 of 6: Updating selected patches attribute table")
        # Calculating distance in kilometers and deleting default Near column
        gp.AddField_management(SelectPatches, "NearDist","DOUBLE","#","#","#","#","NON_NULLABLE","NON_REQUIRED","#")
        gp.CalculateField_management(SelectPatches, "NearDist", "!NEAR_DIST! /1000", "PYTHON", "#")
        gp.DeleteField_management(SelectPatches, "NEAR_DIST")

        # Calculating PatchID column and deleting default Near ID column
        gp.AddField_management(SelectPatches, "PatchID", "LONG", "#", "#", "#", "#", "NON_NULLABLE", "NON_REQUIRED", "#")
        gp.CalculateField_management(SelectPatches, "PatchID", "!NEAR_FID!", "PYTHON", "#")
        gp.DeleteField_management(SelectPatches, "NEAR_FID")
        
        gp.AddMessage("Step 4 of 6: Identifying networks of patches that are functionally connected")
        gp.EucDistance_sa("SelectPatches.shp", "patchdist")
        gp.Con_sa("patchdist", 1, groups, "", "Value <= "+str(float(Input)/2.0))
        gp.RegionGroup_sa(groups, regions, "EIGHT", "WITHIN","ADD_LINK","#")
        gp.RasterToPolygon_conversion(regions, "regionspoly.shp", "SIMPLIFY")
        gp.SpatialJoin_analysis("SelectPatches.shp", "regionspoly.shp", "trial.shp", "JOIN_ONE_TO_ONE", "KEEP_COMMON")
        gp.Copy_management("trial.shp", ConnectedHabitat)
        gp.AddField_management(ConnectedHabitat, "RegionID", "DOUBLE", "#", "#", "#", "#", "NON_NULLABLE", "NON_REQUIRED", "#")
        gp.CalculateField_management(ConnectedHabitat, "RegionID", "!GRIDCODE_1!", "PYTHON", "#")
        gp.AddMessage("   No core habitat, skipping steps 4-6")
    else:
        gp.AddMessage("Step 2 of 6: Identifying networks of patches that are functionally connected")
        gp.EucDistance_sa("NonCore.shp", "patchdist")
        gp.Con_sa("patchdist", 1, groups, "", "VALUE <= "+str(float(Input)/2.0))
        gp.RegionGroup_sa(groups, regions, "EIGHT", "WITHIN","ADD_LINK","#")
        gp.RasterToPolygon_conversion(regions, "regionspoly.shp", "SIMPLIFY")
        gp.SpatialJoin_analysis("NonCore.shp", "regionspoly.shp", "trial.shp", "JOIN_ONE_TO_ONE", "KEEP_COMMON")
        gp.Copy_management("trial.shp", ConnectedHabitat)
        gp.AddField_management(ConnectedHabitat, "RegionID", "DOUBLE", "#", "#", "#", "#", "NON_NULLABLE", "NON_REQUIRED", "#")
        gp.CalculateField_management(ConnectedHabitat, "RegionID", "!GRIDCODE_1!", "PYTHON", "#")
        gp.AddMessage("   No core habitat and no size selected, skipping steps 3-6")
        
    gp.AddMessage("Cleaning the attribute table")
    gp.DeleteField_management(ConnectedHabitat, "Shape_Length")
    gp.DeleteField_management(ConnectedHabitat, "Shape_Area")
    gp.DeleteField_management(ConnectedHabitat, "Join_Count")
    gp.DeleteField_management(ConnectedHabitat, "TARGET_FID")
    gp.DeleteField_management(ConnectedHabitat, "INTERSECT")
    gp.DeleteField_management(ConnectedHabitat, "ID")
    gp.DeleteField_management(ConnectedHabitat, "ID_1")
    gp.DeleteField_management(ConnectedHabitat, "JOIN_FID")
    gp.DeleteField_management(ConnectedHabitat, "GRIDCODE_1")

    if delete in ["TRUE", True]:
        gp.AddMessage("Deleting intermediate data")

        if Size:
            gp.delete_management("SelectPatches.shp")

        gp.delete_management("PatchDist")
        gp.delete_management("groups")
        gp.delete_management("regions")
        gp.delete_management("regionspoly.shp")
        gp.delete_management("PatchGroups.shp")
        gp.AddMessage("Tool has completed!")
    else:
        gp.AddMessage("Tool has completed!")
