## ---------------------------------------------------------------------------
# PatchStatistics.py
# Created on: Fri Dec 03 2010 09:59:36 AM
# Created by: Erin Poor, GIS Analyst, WWF-US
#               erin.poor@wwfus.org
# Usage: PatchStatistics <Input_Patch_Layer> <Output_1__All_Patches_Summary_> <Output_2__Core_Summary> <Output_3__Patch_Summary> <Output_Cores> <Core_Area_Expression> <Output_Patches> <Patch_Area_Expression> 
# Description: 
# This tool calculates geometry statistics for habitat patches. Mean area, mean perimeter, mean perimeter/area ratio and total area are calculated for core habitat patches, non-core habitat patches and all patches in the resulting tables. The cutoff area defining 'core' and 'patch' may be changed depending on the focal species.
# ---------------------------------------------------------------------------
# Replace a layer/table view name with a path to a dataset (which can be a layer file) or create the layer/table view within the script
# The following inputs are layers or table views: "future_luc_suit"
# Import system modules
import sys, string, os, arcgisscripting

# Create the Geoprocessor object
gp = arcgisscripting.create()
gp.overwriteoutput = 1

# Check out any necessary licenses
gp.CheckOutExtension("spatial")

# Set the Geoprocessing environment...
inworkspace = gp.GetParameterAsText(0)
outworkspace = gp.GetParameterAsText(0)
gp.workspace = inworkspace
gp.scratchworkspace = inworkspace

# Script arguments...
Input_Patch_Layer = gp.GetParameterAsText(1)
Summary_Table = gp.GetParameterAsText(2)
Core_Area_Expression = gp.GetParameterAsText(3)
msgArguments = "\nProblem with arguments."

# Local variables...
patches__1_ = gp.GetParameterAsText(1)
patches__2_ = gp.GetParameterAsText(1)
patches__3_ = gp.GetParameterAsText(1)
patches__4_ = gp.GetParameterAsText(1)
patches__5_ = gp.GetParameterAsText(1)
patches__6_ = gp.GetParameterAsText(1)
patches__7_ = gp.GetParameterAsText(1)

gp.AddMessage ("Step 1 of 6: Calculating areas")

# Area...
try:
    gp.AddField_management(patches__1_, "Area", "DOUBLE", "", "", "", "", "NON_NULLABLE", "NON_REQUIRED", "")
    gp.CalculateField_management(patches__2_, "Area", "!shape.area@squarekilometers!", "PYTHON", "")
except:
    raise Exception, msgArguments + gp.GetMessages(2)

# Perimeter...
try:
    gp.AddMessage("Step 2 of 6: Calculating perimeter")
    gp.AddField_management(patches__3_, "Perimeter", "DOUBLE", "", "", "", "", "NON_NULLABLE", "NON_REQUIRED", "")
    gp.CalculateField_management(patches__4_, "Perimeter", "!shape.length@Kilometers!", "PYTHON", "")
except:
    raise Exception, msgArguments + gp.GetMessages(2)
        
# Perimeter/Area Ratio...
try:
    gp.AddMessage("Step 3 of 6: Calculating perimeter/area ratio")
    gp.AddField_management(patches__5_, "PerimArea", "DOUBLE", "", "", "", "", "NON_NULLABLE", "NON_REQUIRED", "")
    gp.CalculateField_management(patches__6_, "PerimArea", "[Perimeter] / [Area]", "VB", "")
except:
    raise Exception, msgArguments + gp.GetMessages(2)
# Adding Type field...
try:
    gp.AddField_management(patches__7_, "Type", "TEXT", "", "", "", "", "NON_NULLABLE", "NON_REQUIRED", "")
    gp.MakeFeatureLayer(patches__7_, "lyr")
    # Id-ing and selecting cores...
    gp.AddMessage("Step 4 of 6: Identifying core habitat")
    gp.SelectLayerByAttribute_management("lyr", "NEW_SELECTION", "Area >= "+Core_Area_Expression+"")
    gp.CalculateField_management("lyr", "Type", "'Core'", "PYTHON", "")
except:
    raise Exception, msgArguments + gp.GetMessages(2)

# Id-ing and selecting non-cores...
try:
    gp.AddMessage("Step 5 of 6: Identifying non-core habitat")
    gp.SelectLayerByAttribute_management("lyr", "NEW_SELECTION", "Area < "+Core_Area_Expression+"")
    gp.CalculateField_management("lyr", "Type", "'Patch'", "PYTHON", "")
except:
    raise Exception, msgArguments + gp.GetMessages(2)
        
# Clearing the selection
try:
    gp.SelectLayerByAttribute_management("lyr", "CLEAR_SELECTION")
    gp.AddMessage ("Step 6 of 6: Assembling summary statistics")
    gp.Statistics_analysis(patches__7_, Summary_Table, "Area MEAN;Perimeter MEAN;Perimeter SUM;PerimArea MEAN;Area SUM", "Type")
except:
    raise Exception, msgArguments + gp.GetMessages(2)
        
gp.AddMessage ("Patch Statistics have been calculated for your landscape!")
