# ---------------------------------------------------------------------------
# Suitability.py
# Created on: Wed Dec 01 2010 04:29:21 PM 
# Edited on: Thurs March 01 2012
# Created by: Erin Poor, GIS Analyst, WWF-US
#               erin.poor@wwfus.org
# Usage: suitability <Hydrology> <Water_Weight> <Mines> <Mines_Weight> <Protected_Areas_Weight> <Protected_Areas> <Land_Cover> <Land_Cover_Weight> <Towns> <Cities> <Settlement_Weight> <Minor_Roads> <Major_Roads> <Roads_Weight> <Suitable_Habitat> <Suitable_Patches> 
# ---------------------------------------------------------------------------

# Import system modules
import sys, string, os, arcgisscripting

# Create the Geoprocessor object
gp = arcgisscripting.create()
gp.OverWriteOutput = 1

# Check out any necessary licenses
gp.CheckOutExtension("spatial")
Land_Cover = gp.GetParameterAsText(19)

#Set Geoprocessing environment...
inworkspace = gp.GetParameterAsText(0)
outworkspace = gp.GetParameterAsText(0)
gp.workspace = inworkspace
gp.scratchworkspace = gp.GetParameterAsText(0)
gp.mask = Land_Cover
gp.snapraster = Land_Cover
gp.extent = Land_Cover

# Script arguments...
# Getting hydrology layers...
Rivers = gp.GetParameterAsText(1)
Lakes = gp.GetParameterAsText(2)
if Rivers or Lakes:
        Water_Reclass = gp.GetParameterAsText(3)
        Water_Weight = gp.GetParameterAsText(4)
else:
        Water_Weight = 0
        Water_Reclass = 0

#Getting mines layer...
Mines = gp.GetParameterAsText(5)
if Mines:
        Mines_Reclass = gp.GetParameterAsText(6)
        Mines_Weight = gp.GetParameterAsText(7)
else:
        Mines_Weight = 0
        Mines_Reclass = 0

# Getting protected areas layer...
Protected_Areas = gp.GetParameterAsText(8)
if Protected_Areas:
        Protected_Areas_Field = gp.GetParameterAsText(9)
        Protected_Areas_Reclass = gp.GetParameterAsText(10)
        Protected_Areas_Weight = gp.GetParameterAsText(11)
else:
        Protected_Areas_Field = 0    
        Protected_Areas_Reclass = 0
        Protected_Areas_Weight = 0

#Getting prey occupancy layer...
PreyOcc = gp.GetParameterAsText(12)
if PreyOcc:
        PreyOccField = gp.GetParameterAsText(13)
        PreyOccReclass = gp.GetParameterAsText(14)
        PreyOccWeight = gp.GetParameterAsText(15)
else:
        PreyOccField = 0
        PreyOccReclass = 0
        PreyOccWeight = 0

#Getting poaching layer...
Poach = gp.GetParameterAsText(16)
if Poach:
        PoachReclass = gp.GetParameterAsText(17)
        PoachWeight = gp.GetParameterAsText(18)
else:
        PoachReclass = 0
        PoachWeight = 0


# Getting land cover layer...
Land_Cover_Field = gp.GetParameterAsText(20)
Land_Cover_Reclass = gp.GetParameterAsText(21)
Land_Cover_Weight = gp.GetParameterAsText(22)

#Getting Slope layer...
Slope = gp.GetParameterAsText(23)
if Slope:
        Slope_Reclass = gp.GetParameterAsText(24)
	SlopeWeight = gp.GetParameterAsText(25)
else: 
        Slope_Reclass = 0
	SlopeWeight = 0

#Getting villages layer...
Village = gp.GetParameterAsText(26)
if Village:
        VillageReclass = gp.GetParameterAsText(27)
else:
        VillageReclass = 0

# Getting settlements layer...
Towns = gp.GetParameterAsText(28)
Towns_Reclass = gp.GetParameterAsText(29)
Cities = gp.GetParameterAsText(30)
Cities_Reclass = gp.GetParameterAsText(31)
Settlement_Weight = gp.GetParameterAsText(32)

# Getting roads layer...
Minor_Roads = gp.GetParameterAsText(33)
Minor_Roads_Reclass = gp.GetParameterAsText (34)
Major_Roads = gp.GetParameterAsText(35)
Major_Roads_Reclass = gp.GetParameterAsText(36)
Roads_Weight = gp.GetParameterAsText(37)

suithab = gp.GetParameterAsText(38)
GHT = gp.GetParameterAsText(39)
suitpatches = gp.GetParameterAsText(40)

delete = gp.GetParameterAsText(41).upper() 

msgArguments = "\nProblem with arguments."

# Local variables...

riversdist = "riversdist"
lakesdist = "lakesdist"
rivers_re = "rivers_re"
lakes_re = "lakes_re"
waterdist = "waterdist"
Water = "Water"
waterweight = "waterweight"
minesdist = "minesdist"
mines_re = "mines_re"
minesweight = "minesweight"
pas_weight = "pas_weight"
pas_re = "pas_re"
prey_re = "prey_re"
prey_weight = "prey_weight"
poachdist = "poachdist"
poach_re = "poach_re"
poachweight = "poachweight"
lc_re = "lc_re"
lc_weight = "lc_weight"
sl_weight = "sl_weight"
Slope_re = "Slope_re"
villagedist = "villagedist"
village_re = "village_re"
towndist = "towndist"
citydist = "citydist"
towns_re = "towns_re"
city_re = "city_re"
Settlements = "Settlements"
settleweight = "settleweight"
minroaddist = "minroaddist"
majroaddist = "majroaddist"
minor_re = "minor_re"
major_re = "major_re"
Roads = "Roads"
roadsweight = "roadsweight"
extractout = "extractout"
conout = "conout"
regionout = "regionout"

def checkCellSize(thedata):
        desc=gp.Describe(thedata)
        CellWidth = desc.MeanCellWidth
        CellHeight = desc.MeanCellHeight
        return int((CellHeight+CellWidth)/2.0)

LC_cellsize = checkCellSize(Land_Cover)
gp.cellsize = LC_cellsize

###########################################################################################################################
########################################################## WATER###########################################################
###########################################################################################################################
gp.AddMessage("Step 1 of 11")
try:
        if Lakes or Rivers:
                if Lakes and Rivers:
                        gp.AddMessage("   Calculating euclidean distance from rivers")
                        gp.EucDistance_sa(Rivers, riversdist, "", str(LC_cellsize))

                        gp.AddMessage("   Reclassifying distance from rivers")
                        gp.Reclassify_sa(riversdist, "Value", Water_Reclass, rivers_re, "DATA")

                        gp.AddMessage("   Calculating euclidean distance from lakes")
                        gp.EucDistance_sa(Lakes, lakesdist, "", str(LC_cellsize))

                        gp.AddMessage("   Reclassifying distance from rivers")
                        gp.Reclassify_sa(lakesdist, "Value", Water_Reclass, lakes_re, "DATA")

                        gp.CellStatistics_sa("lakes_re; rivers_re", Water, "MINIMUM")
                        gp.Times_sa(Water, Water_Weight, waterweight)

                if Rivers:
                        gp.AddMessage("   Calculating euclidean distance from rivers")
                        gp.EucDistance_sa(Rivers, riversdist, "", str(LC_cellsize))
                        gp.AddMessage("   Reclassifying distance from rivers")
                        gp.Reclassify_sa(riversdist, "Value", Water_Reclass, rivers_re, "DATA")
                        gp.Times_sa(rivers_re, Water_Weight, waterweight)
                
                if Lakes:
                        gp.AddMessage("   Calculating euclidean distance from lakes")
                        gp.EucDistance_sa(Lakes, lakesdist, "", str(LC_cellsize))
                        gp.AddMessage("   Reclassifying distance from rivers")
                        gp.Reclassify_sa(lakesdist, "Value", Water_Reclass, lakes_re, "DATA")
                        gp.Times_sa(lakes_re, Water_Weight, waterweight)
        else: gp.AddMessage("   No hydrology data, skipping to Step 2")      
except:
    raise Exception, msgArguments + gp.GetMessages(2)
    
        
###########################################################################################################################
########################################################## MINES ##########################################################
###########################################################################################################################
gp.AddMessage("Step 2 of 11")
try:
        if Mines:
                gp.AddMessage("   Calculating euclidean distance from mines")
                gp.EucDistance_sa(Mines, minesdist, "", str(LC_cellsize))
                gp.AddMessage("   Reclassifying distance from mines")
                gp.Reclassify_sa(minesdist, "Value", Mines_Reclass, mines_re, "DATA")
                gp.Times_sa(mines_re, Mines_Weight, minesweight)
        else:
                gp.AddMessage("   No mines data, skipping to Step 3")
except:
    raise Exception, msgArguments + gp.GetMessages(2)

        
###########################################################################################################################
##################################################### PROTECTED AREAS  ####################################################
###########################################################################################################################
gp.AddMessage("Step 3 of 11")
try:    
        if Protected_Areas:
                gp.AddMessage("   Reclassifying protected areas")
                gp.Reclassify_sa(Protected_Areas,Protected_Areas_Field,Protected_Areas_Reclass,"pas_re","DATA")
                gp.Times_sa(pas_re, Protected_Areas_Weight, pas_weight)
        else:
                gp.AddMessage("   No protected areas data, skipping to Step 4")
except:
    raise Exception, msgArguments + gp.GetMessages(2)

###########################################################################################################################
##################################################### PREY OCCUPANCY  #####################################################
###########################################################################################################################
gp.AddMessage("Step 4 of 11")
try:    
        if PreyOcc:
                gp.AddMessage("   Reclassifying prey occupancy")
                gp.Reclassify_sa(PreyOcc,PreyOccField, PreyOccReclass,"prey_re","DATA")
                gp.Times_sa(prey_re, PreyOccWeight, prey_weight)
        else:
                gp.AddMessage("   No prey occupancy data, skipping to Step 5")
except:
    raise Exception, msgArguments + gp.GetMessages(2)
###########################################################################################################################
##################################################### POACHING LOCATIONS  #################################################
###########################################################################################################################
gp.AddMessage("Step 5 of 11")
try:
        if Poach:
                gp.AddMessage("   Calculating euclidean distance from poachers")
                gp.EucDistance_sa(Poach, poachdist, "", str(LC_cellsize))
                gp.AddMessage("   Reclassifying distance from poachers")
                gp.Reclassify_sa("poachdist", "Value", PoachReclass, "poach_re", "DATA")
                gp.Times_sa(poach_re, PoachWeight, poachweight)
        else:
                gp.AddMessage("   No poacher data, skipping to Step 6")
except:
    raise Exception, msgArguments + gp.GetMessages(2)
###########################################################################################################################
####################################################### LAND COVER  #######################################################
###########################################################################################################################
gp.AddMessage("Step 6 of 11")
try:
        gp.AddMessage("   Reclassifying land cover")
        gp.Reclassify_sa(Land_Cover,Land_Cover_Field ,Land_Cover_Reclass,"lc_re","DATA")
        gp.Times_sa(lc_re, Land_Cover_Weight, lc_weight)
except:
    raise Exception, msgArguments + gp.GetMessages(2)
###########################################################################################################################
########################################################## Slope  #########################################################
###########################################################################################################################
gp.AddMessage("Step 7 of 11")
try:
        if Slope:
		gp.AddMessage ("   Reclassifying slope")
		gp.Reclassify_sa(Slope, "Value", Slope_Reclass, "Slope_re", "DATA")
		gp.Times_sa(Slope_re, SlopeWeight, sl_weight)
	else:
                gp.AddMessage("   No slope data, skipping to Step 8")
except:
	raise Exception, msgArguments + gp.GetMessages(2)
###########################################################################################################################
####################################################### SETTLEMENTS #######################################################
###########################################################################################################################
gp.AddMessage("Step 8 of 11")
try:
        if Village:
                gp.AddMessage("   Calculating euclidean distance from villages")
                gp.EucDistance_sa(Village, villagedist, "", str(LC_cellsize))

                gp.AddMessage("   Reclassifying distance from villages")
                gp.Reclassify_sa(villagedist, "Value", VillageReclass, village_re, "DATA")
                
                gp.AddMessage("   Calculating euclidean distance from towns")
                gp.EucDistance_sa(Towns, towndist, "", str(LC_cellsize))

                gp.AddMessage("   Calculating euclidean distance from cities")
                gp.EucDistance_sa(Cities, citydist, "", str(LC_cellsize))

                gp.AddMessage("   Reclassifying distance from towns")
                gp.Reclassify_sa(towndist, "Value", Towns_Reclass, towns_re, "DATA")

                gp.AddMessage("   Reclassifying distance from cities")
                gp.Reclassify_sa(citydist, "Value", Cities_Reclass, city_re, "DATA")
                                
                gp.CellStatistics_sa("village_re;towns_re;city_re", Settlements, "MINIMUM")
                gp.Times_sa(Settlements, Settlement_Weight, settleweight)

        else:
                gp.AddMessage("   Calculating euclidean distance from towns")
                gp.EucDistance_sa(Towns, towndist, "", str(LC_cellsize))

                gp.AddMessage("   Calculating euclidean distance from cities")
                gp.EucDistance_sa(Cities, citydist, "", str(LC_cellsize))

                gp.AddMessage("   Reclassifying distance from towns")
                gp.Reclassify_sa(towndist, "Value", Towns_Reclass, towns_re, "DATA")

                gp.AddMessage("   Reclassifying distance from cities")
                gp.Reclassify_sa(citydist, "Value", Cities_Reclass, city_re, "DATA")
                                
                gp.CellStatistics_sa("towns_re;city_re", Settlements, "MINIMUM")
                gp.Times_sa(Settlements, Settlement_Weight, settleweight)
except:
    raise Exception, msgArguments + gp.GetMessages(2)


###########################################################################################################################
####################################################### ROADS #############################################################
###########################################################################################################################
gp.AddMessage("Step 9 of 11")
try:                                           
        gp.AddMessage("   Calculating euclidean distance from minor roads")
        gp.EucDistance_sa(Minor_Roads, minroaddist, "", str(LC_cellsize))

        gp.AddMessage("   Calculating euclidean distance from major roads")
        gp.EucDistance_sa(Major_Roads, majroaddist, "", str(LC_cellsize))

        gp.AddMessage("   Reclassifying distance from minor roads")
        gp.Reclassify_sa(minroaddist, "Value", Minor_Roads_Reclass, minor_re, "DATA")

        gp.AddMessage("   Reclassifying distance from major roads")
        gp.Reclassify_sa(majroaddist, "Value", Major_Roads_Reclass, major_re, "DATA")

        gp.CellStatistics_sa("minor_re; major_re", Roads, "MINIMUM")
        gp.Times_sa(Roads, Roads_Weight, roadsweight)

except:
    raise Exception, msgArguments + gp.GetMessages(2)

        
###########################################################################################################################
####################################################### COMBINE ###########################################################
###########################################################################################################################
gp.AddMessage("Step 10 of 11")
try:
        gp.AddMessage("   Identifying suitable habitat")
        if Slope:
                SHExpr = ("sl_weight + lc_weight + roadsweight + settleweight")
        elif Rivers and Slope:
                SHExpr = ("waterweight + sl_weight + lc_weight + roadsweight + settleweight")
        elif Lakes and Slope: 
                SHExpr = ("waterweight + sl_weight + lc_weight + roadsweight + settleweight")
        elif Slope and Mines:
		SHExpr = ("sl_weight + minesweight + lc_weight + roadsweight + settleweight")
        elif Slope and PreyOcc:
		SHExpr = ("sl_weight + prey_weight + lc_weight + roadsweight + settleweight")	
        elif Slope and Poach:
		SHExpr = ("sl_weight + poachweight + lc_weight + roadsweight + settleweight")
        elif Slope and Protected_Areas:
		SHExpr = ("sl_weight + pas_weight + lc_weight + roadsweight + settleweight")
        elif Slope and Rivers and Poach:
		SHExpr = ("sl_weight + waterweight + poachweight + lc_weight + roadsweight + settleweight")
        elif Slope and Lakes and Poach:
		SHExpr = ("sl_weight + waterweight + poachweight + lc_weight + roadsweight + settleweight")	
        elif Slope and Poach and Mines:
		SHExpr = ("sl_weight + poachweight + minesweight + lc_weight + roadsweight + settleweight")
        elif Slope and Poach and PreyOcc:
		SHExpr = ("sl_weight + prey_weight + poachweight + lc_weight + roadsweight + settleweight")
        elif Slope and Poach and Protected_Areas:
		SHExpr = ("sl_weight + poachweight + pas_weight + lc_weight + roadsweight + settleweight")
        elif Lakes and Rivers and Slope:
                SHExpr = ("waterweight + sl_weight + lc_weight + roadsweight + settleweight")
        elif Slope and Rivers and Mines:
 		SHExpr = ("sl_weight + waterweight + minesweight + lc_weight + roadsweight + settleweight")
        elif Slope and Rivers and PreyOcc:
		SHExpr = ("sl_weight + prey_weight + waterweight + lc_weight + roadsweight + settleweight")
        elif Slope and Rivers and Protected_Areas:
		SHExpr = ("sl_weight + pas_weight + waterweight + lc_weight + roadsweight + settleweight")
        elif Slope and Rivers and Lakes:
		SHExpr = ("sl_weight + waterweight + lc_weight + roadsweight + settleweight")
        elif Slope and Mines and PreyOcc:
		SHExpr = ("sl_weight + prey_weight + minesweight + lc_weight + roadsweight + settleweight")
        elif Slope and Mines and Protected_Areas:
		SHExpr = ("sl_weight + pas_weight + minesweight + lc_weight + roadsweight + settleweight")
        elif Slope and Mines and Lakes:
		SHExpr = ("sl_weight + waterweight + minesweight + lc_weight + roadsweight + settleweight")
        elif Slope and PreyOcc and Protected_Areas:
		SHExpr = ("sl_weight + prey_weight + pas_weight + lc_weight + roadsweight + settleweight")
        elif Slope and PreyOCc and Lakes:
		SHExpr = ("sl_weight + waterweight + prey_weight + lc_weight + roadsweight + settleweight")
        elif Slope and Lakes and Protected_Areas:
		SHExpr = ("sl_weight + waterweight + pas_weight + lc_weight + roadsweight + settleweight")
        elif Slope and Poach and Rivers and Mines:
		SHExpr = ("sl_weight + poachweight + waterweight + minesweight + lc_weight + roadsweight + settleweight")
        elif Slope and Poach and Rivers and PreyOcc:
		SHExpr = ("sl_weight + poachweight + waterweight + prey_weight + lc_weight + roadsweight + settleweight")
        elif Slope and Poach and Rivers and Protected_Areas:
		SHExpr = ("sl_weight + poachweight + pas_weight + waterweight + lc_weight + roadsweight + settleweight")
        elif Slope and Poach and Rivers and Lakes:
		SHExpr = ("sl_weight + poachweight + waterweight + lc_weight + roadsweight + settleweight")
        elif Slope and Poach and Mines and Protected_Areas:
		SHExpr = ("sl_weight + poachweight + pas_weight + minesweight + lc_weight + roadsweight + settleweight")
        elif Slope and Poach and Mines and Lakes:
		SHExpr = ("sl_weight + waterweight + poachweight + minesweight + lc_weight + roadsweight + settleweight")
        elif Slope and Poach and PreyOcc and Mines:
		SHExpr = ("sl_weight + poachweight + prey_weight + minesweight + lc_weight + roadsweight + settleweight")
        elif Slope and Poach and PreyOcc and Protected_Areas:
		SHExpr = ("sl_weight + poachweight + prey_weight + pas_weight + lc_weight + roadsweight + settleweight")
        elif Slope and Poach and PreyOcc and Lakes:
		SHExpr = ("sl_weight + waterweight + poachweight + prey_weight + lc_weight + roadsweight + settleweight")
        elif Slope and Poach and Protected_Areas and Lakes:
		SHExpr = ("sl_weight + waterweight + poachweight + pas_weight + lc_weight + roadsweight + settleweight")
        elif Slope and Rivers and Mines and PreyOcc:
		SHExpr = ("sl_weight + prey_weight + waterweight + minesweight + lc_weight + roadsweight + settleweight")
        elif Slope and Rivers and Mines and Protected_Areas:
		SHExpr = ("sl_weight + pas_weight + waterweight + minesweight + lc_weight + roadsweight + settleweight")
        elif Slope and Rivers and Mines and Lakes:
		SHExpr = ("sl_weight + waterweight + minesweight + lc_weight + roadsweight + settleweight")
        elif Slope and Rivers and PreyOcc and Protected_Areas:
		SHExpr = ("sl_weight + prey_weight + pas_weight + waterweight + lc_weight + roadsweight + settleweight")	
        elif Slope and Rivers and PreyOcc and Lakes:
		SHExpr = ("sl_weight + waterweight + prey_weight + lc_weight + roadsweight + settleweight")
        elif Slope and Rivers and Protected_Areas and Lakes:
		SHExpr = ("sl_weight + pas_weight + waterweight + lc_weight + roadsweight + settleweight")
        elif Slope and Mines and PreyOcc and Protected_Areas:
		SHExpr = ("sl_weight + prey_weight + pas_weight + minesweight + lc_weight + roadsweight + settleweight")
        elif Slope and Mines and PreyOcc and Lakes:
		SHExpr = ("sl_weight + waterweight + prey_weight + minesweight + lc_weight + roadsweight + settleweight")
        elif Slope and Mines and Lakes and Protected_Areas:
		SHExpr = ("sl_weight + waterweight + pas_weight + minesweight + lc_weight + roadsweight + settleweight")
        elif Slope and PreyOcc and Protected_Areas and Lakes:
		SHExpr = ("sl_weight + waterweight + prey_weight + pas_weight + lc_weight + roadsweight + settleweight")
        elif Slope and Poach and Rivers and Mines and PreyOcc:
		SHExpr = ("sl_weight + poachweight + prey_weight + waterweight + minesweight + lc_weight + roadsweight + settleweight")
        elif Slope and Poach and Rivers and Mines and Protected_Areas:
		SHExpr = ("sl_weight + poachweight + pas_weight + waterweight + minesweight + lc_weight + roadsweight + settleweight")
        elif Slope and Poach and Rivers and Mines and Lakes:
		SHExpr = ("sl_weight + poachweight + waterweight + minesweight + lc_weight + roadsweight + settleweight")
        elif Slope and Poach and Rivers and PreyOcc and Protected_Areas:
		SHExpr = ("sl_weight + poachweight + prey_weight + pas_weight + waterweight + lc_weight + roadsweight + settleweight")
        elif Slope and Poach and Rivers and PreyOcc and Lakes:
		SHExpr = ("sl_weight + poachweight + prey_weight + waterweight + lc_weight + roadsweight + settleweight")
        elif Slope and Poach and Rivers and Protected_Areas and Lakes:
		SHExpr = ("sl_weight + poachweight + pas_weight + waterweight + lc_weight + roadsweight + settleweight")
        elif Slope and Poach and Mines and PreyOcc and Protected_Areas:
		SHExpr = ("sl_weight + poachweight + prey_weight + pas_weight + minesweight + lc_weight + roadsweight + settleweight")
        elif Slope and Poach and Mines and PreyOcc and Lakes:
		SHExpr = ("sl_weight + poachweight + prey_weight + waterweight + minesweight + lc_weight + roadsweight + settleweight")
        elif Slope and Poach and Mines and Protected_Areas and Lakes:
		SHExpr = ("sl_weight + poachweight + waterweight + pas_weight + minesweight + lc_weight + roadsweight + settleweight")
        elif Slope and Poach and PreyOcc and Protected_Areas and Lakes:
		SHExpr = ("sl_weight + poachweight + prey_weight + waterweight + pas_weight + lc_weight + roadsweight + settleweight")
        elif Slope and Rivers and Mines and PreyOcc and Protected_Areas:
		SHExpr = ("sl_weight + pas_weight + prey_weight + waterweight + minesweight + lc_weight + roadsweight + settleweight")
        elif Slope and Rivers and Mines and PreyOcc and Lakes:
		SHExpr = ("sl_weight + waterweight + minesweight + prey_weight + lc_weight + roadsweight + settleweight")
        elif Slope and Rivers and PreyOcc and Protected_Areas and Lakes:
		SHExpr = ("sl_weight + pas_weight + prey_weight + waterweight + lc_weight + roadsweight + settleweight")
        elif Slope and Rivers and Lakes and Protected_Areas and Mines:
		SHExpr = ("sl_weight + pas_weight + waterweight + minesweight + lc_weight + roadsweight + settleweight")
        elif Slope and Mines and PreyOcc and Protected_Areas and Lakes:
		SHExpr = ("sl_weight + pas_weight + prey_weight + minesweight + waterweight + lc_weight + roadsweight + settleweight")
        elif Slope and Poach and Rivers and Mines and PreyOcc and Protected_Areas and Lakes:
		SHExpr = ("sl_weight + poachweight + waterweight + minesweight + prey_weight + pas_weight + lc_weight + roadsweight + settleweight")
        elif Slope and Rivers and Mines and PreyOcc and Protected_Areas and Lakes:
		SHExpr = ("sl_weight + pas_weight + prey_weight + waterweight + minesweight + lc_weight + roadsweight + settleweight")
        elif Slope and Poach and  Mines and PreyOcc and Protected_Areas and Lakes:
		SHExpr = ("sl_weight + poachweight + prey_weight + waterweight + minesweight + pas_weight + lc_weight + roadsweight + settleweight")
        elif Slope and Poach and Rivers and PreyOcc and Protected_Areas and Lakes:
		SHExpr = ("sl_weight + poachweight + prey_weight + waterweight + pas_weight + lc_weight + roadsweight + settleweight")
        elif Slope and Poach and Rivers and Mines and Protected_Areas and Lakes:
		SHExpr = ("sl_weight + poachweight + pas_weight + waterweight + minesweight + lc_weight + roadsweight + settleweight")
        elif Slope and Poach and Rivers and Mines and PreyOcc and Lakes:
		SHExpr = ("sl_weight + poachweight + prey_weight + waterweight + minesweight + lc_weight + roadsweight + settleweight")
        elif Slope and Poach and Rivers and Mines and PreyOcc and Protected_Areas:
		SHExpr = ("minesweight + sl_weight + poachweight + waterweight + prey_weight + pas_weight + lc_weight + roadsweight + settleweight")
        elif Rivers and Lakes and Mines and Protected_Areas and PreyOcc:
                SHExpr = ("minesweight + lc_weight + roadsweight + settleweight + pas_weight + waterweight + prey_weight")
        elif Protected_Areas and Mines and Lakes and Rivers and Poach:
                SHExpr = ("waterweight + minesweight + poachweight + settleweight + lc_weight + roadsweight")
        elif Mines and Lakes and Rivers and Poach and PreyOcc:
                SHExpr = ("prey_weight + minesweight + waterweight + poachweight + settleweight + lc_weight + roadsweight")
        elif PreyOcc and Protected_Areas and Lakes and Rivers and Poach:
                SHExpr = ("prey_weight + pas_weight + poachweight + waterweight + settleweight + lc_weight + roadsweight")
        elif PreyOcc and Protected_Areas and Mines and Rivers and Poach:
                SHExpr = ("prey_weight + pas_weight + minesweight + waterweight + poachweight + settleweight + lc_weight + roadsweight")
        elif PreyOcc and Protected_Areas and Mines and Lakes and Poach:
                SHExpr = ("prey_weight + pas_weight + minesweight + waterweight + poachweight + settleweight + lc_weight + roadsweight")
        elif Protected_Areas and Mines and Lakes and Poach:
                SHExpr = ("pas_weight + minesweight + waterweight + poachweight + settleweight + lc_weight + roadsweight")
        elif Rivers and Mines and Protected_Areas and PreyOcc:
                SHExpr = ("pas_weight + waterweight + minesweight + prey_weight + settleweight + lc_weight + roadsweight")
        elif Protected_Areas and Mines and Rivers and Poach:
                SHExpr = ("pas_weight + minesweight + waterweight + poachweight + settleweight + lc_weight + roadsweight")
        elif Protected_Areas and Mines and PreyOcc and Poach:
                SHExpr = ("pas_weight + minesweight + prey_weight + poachweight + settleweight + lc_weight + roadsweight")
        elif Mines and Protected_Areas and Lakes and PreyOcc:
                SHExpr = ("pas_weight + waterweight + minesweight + prey_weight + settleweight + lc_weight + roadsweight")
        elif Rivers and Lakes and Mines and Protected_Areas:
                SHExpr = ("minesweight + lc_weight + roadsweight + settleweight + pas_weight + waterweight")
        elif Rivers and Lakes and Mines and PreyOcc:
                SHExpr = ("waterweight + minesweight + prey_weight + settleweight + lc_weight + roadsweight")
        elif Lakes and Rivers and Protected_Areas and PreyOcc:
                SHExpr = ("pas_weight + waterweight + prey_weight + settleweight + lc_weight + roadsweight")
        elif Mines and Lakes and Rivers and Poach:
                SHExpr = ("minesweight + waterweight + poachweight + settleweight + lc_weight + roadsweight")
        elif Mines and Lakes and PreyOcc and Poach:
                SHExpr = ("minesweight + waterweight + prey_weight + poachweight + settleweight + lc_weight + roadsweight")
        elif PreyOcc and Protected_Areas and Lakes and Poach:
                SHExpr = ("prey_weight + pas_weight + waterweight + poachweight + settleweight + lc_weight + roadsweight")
        elif PreyOcc and Protected_Areas and Rivers and Poach:
                SHExpr = ("prey_weight + pas_weight + waterweight + poachweight + settleweight + lc_weight + roadsweight")
        elif PreyOcc and Mines and Lakes and Poach:
                SHExpr = ("prey_weight + minesweight + waterweight + poachweight + settleweight + lc_weight + roadsweight")
        elif PreyOcc and Lakes and Rivers and Poach:
                SHExpr = ("prey_weight + waterweight + poachweight + settleweight + lc_weight + roadsweight")
        elif PreyOcc and Mines and Rivers and Poach:
                SHExpr = ("prey_weight + minesweight + poachweight + settleweight + lc_weight + roadsweight")
        elif PreyOcc and Protected_Areas and Poach:
                SHExpr = ("prey_weight + pas_weight + poachweight + settleweight + lc_weight + roadsweight")
        elif PreyOcc and Mines and Poach:
                SHExpr = ("prey_weight + minesweight + poachweight + settleweight + lc_weight + roadsweight")
        elif PreyOcc and Lakes and Poach:
                SHExpr = ("prey_weight + waterweight + poachweight + settleweight + lc_weight + roadsweight")
        elif PreyOcc and Rivers and Poach:
                SHExpr = ("prey_weight + waterweight + poachweight  + settleweight + lc_weight + roadsweight")
        elif Protected_Areas and Mines and Poach:
                SHExpr = ("pas_weight + minesweight + poachweight + settleweight + lc_weight + roadsweight")
        elif Protected_Areas and Lakes and Poach:
                SHExpr = ("pas_weight + waterweight + poachweight + settleweight + lc_weight + roadsweight")
        elif Protected_Areas and Rivers and Poach:
                SHExpr = ("pas_weight + waterweight + poachweight + settleweight + lc_weight + roadsweight")
        elif Mines and Lakes and Poach:
                SHExpr = ("minesweight + waterweight + poachweight + settleweight + lc_weight + roadsweight")
        elif Mines and Rivers and Poach:
                SHExpr = ("minesweight + waterweight + poachweight + settleweight + lc_weight + roadsweight")
        elif Lakes and Rivers and Poach:
                SHExpr = ("waterweight + poachweight + settleweight + lc_weight + roadsweight")
        elif Lakes and Mines and PreyOcc:
                SHExpr = ("waterweight + minesweight + prey_weight + settleweight + lc_weight + roadsweight")
        elif Lakes and PreyOcc and Protected_Areas:
                SHExpr = ("waterweight + prey_weight + pas_weight + settleweight + lc_weight + roadsweight")
        elif Rivers and Mines and PreyOcc:
                SHExpr = ("waterweight + minesweight + prey_weight + settleweight + lc_weight + roadsweight")
        elif Rivers and Protected_Areas and PreyOcc:
                SHExpr = ("waterweight + pas_weight + prey_weight + settleweight + lc_weight + roadsweight")
        elif Mines and Protected_Areas and PreyOcc:
                SHExpr = ("minesweight + pas_weight + prey_weight + settleweight + lc_weight + roadsweight")
        elif Rivers and Mines and Protected_Areas:
                SHExpr = ("minesweight + lc_weight + roadsweight + waterweight + settleweight + pas_weight")
        elif Lakes and Mines and Protected_Areas:
                SHExpr = ("minesweight + lc_weight + roadsweight + settleweight + pas_weight + waterweight")
        elif Lakes and Rivers and PreyOcc:
                SHExpr = ("waterweight + prey_weight + settleweight + lc_weight + roadsweight")
        elif Rivers and Lakes and Mines:
                SHExpr = ("minesweight + lc_weight + roadsweight + settleweight + waterweight")
        elif Rivers and Lakes and Protected_Areas:
                SHExpr = ("lc_weight + roadsweight + settleweight + pas_weight + waterweight")
        elif PreyOcc and Poach:
                SHExpr = ("prey_weight + poachweight + settleweight + lc_weight + roadsweight")
        elif Protected_Areas and Poach:
                SHExpr = ("pas_weight + poachweight + settleweight + lc_weight + roadsweight")
        elif Mines and Poach:
                SHExpr = ("minesweight + poachweight + settleweight + lc_weight + roadsweight")
        elif Lakes and Poach:
                SHExpr = ("waterweight + poachweight + settleweight + lc_weight + roadsweight")
        elif Rivers and Poach:
                SHExpr = ("waterweight + poachweight + settleweight + lc_weight + roadsweight")
        elif Rivers and Mines:
                SHExpr = ("minesweight + lc_weight + roadsweight + settleweight + waterweight")
        elif Lakes and Mines:
                SHExpr = ("minesweight + lc_weight + roadsweight + settleweight + waterweight")
        elif Rivers and Protected_Areas:
                SHExpr = ("lc_weight + roadsweight + settleweight + pas_weight + waterweight")
        elif Lakes and Protected_Areas:
                SHExpr = ("lc_weight + roadsweight + settleweight + pas_weight + waterweight")
        elif Mines and Protected_Areas:
                SHExpr = ("minesweight + lc_weight + roadsweight + settleweight + pas_weight")   
        elif Rivers and Lakes:
                SHExpr = ("lc_weight + roadsweight + settleweight + waterweight")
        elif Lakes and PreyOcc:
                SHExpr = ("waterweight + prey_weight + settleweight + lc_weight + roadsweight")
        elif Rivers and PreyOcc:
                SHExpr = ("waterweight + prey_weight + settleweight + lc_weight + roadsweight")
        elif Mines and PreyOcc:
                SHExpr = ("minesweight + prey_weight + settleweight + lc_weight + roadsweight")
        elif PreyOcc and Protected_Areas:
                SHExpr = ("prey_weight + pas_weight + settleweight + lc_weight + roadsweight")
        elif Mines:
                SHExpr = ("minesweight + lc_weight + roadsweight + settleweight")
        elif Protected_Areas:
                SHExpr = ("lc_weight + roadsweight + settleweight + pas_weight")
        elif PreyOcc:
                SHExpr = ("lc_weight + roadsweight + settleweight + prey_weight")
        elif Poach:
                SHExpr = ("poachweight + lc_weight + roadsweight + settleweight")
        else:
                SHExpr = ("lc_weight + roadsweight + settleweight")

except:
    raise Exception, msgArguments + gp.GetMessages(2)

gp.AddMessage("Step 11 of 11")
try:
        gp.SingleOutputMapAlgebra_sa(""+SHExpr+"", suithab, "")
        gp.ExtractByAttributes_sa(suithab, "Value >= "+GHT+"", extractout) 
        gp.SingleOutputMapAlgebra_sa("con(extractout >= "+GHT+", 1, 0)", conout)
        gp.RegionGroup_sa(conout, regionout, "FOUR", "WITHIN", "ADD_LINK", "")
        gp.RasterToPolygon_conversion(regionout, suitpatches, "SIMPLIFY", "VALUE")

except:
    raise Exception, msgArguments + gp.GetMessages(2)


###########################################################################################################################
####################################################### DELETE ############################################################
###########################################################################################################################        

if delete in ["TRUE", True]:
        gp.AddMessage("   Deleting intermediate data")

        if Rivers:
                gp.delete_management("riversdist")
                gp.delete_management("rivers_re")
                gp.delete_management("waterweight")
        if Lakes: 
                gp.delete_management("lakesdist")
                gp.delete_management("lakes_re")
                gp.delete_management("waterweight")
        if Lakes and Rivers:
                gp.delete_management("Water")
                gp.delete_management("waterweight")
        if Mines:
                gp.delete_management("minesdist")
                gp.delete_management("mines_re")
                gp.delete_management("minesweight")
        if Protected_Areas:
                gp.delete_management("pas_weight")
                gp.delete_management("pas_re")
        if PreyOcc:
                gp.delete_management("prey_weight")
                gp.delete_management("prey_re")
        if Poach:
                gp.delete_management("poachdist")
                gp.delete_management("poachweight")
                gp.delete_management("poach_re")
        if Village:
                gp.delete_management("villagedist")
                gp.delete_management("village_re")

        gp.delete_management("lc_re")
        gp.delete_management("lc_weight")

        gp.delete_management("towndist")
        gp.delete_management("citydist")
        gp.delete_management("towns_re")
        gp.delete_management("city_re")
        gp.delete_management("Settlements")
        gp.delete_management("settleweight")

        gp.delete_management("minroaddist")
        gp.delete_management("majroaddist")
        gp.delete_management("minor_re")
        gp.delete_management("major_re")
        gp.delete_management("Roads")
        gp.delete_management("roadsweight")

        gp.delete_management("extractout")
        gp.delete_management("conout")
        gp.delete_management("regionout")
        gp.AddMessage("Congratulations! You identified suitable habitat!")

else: 
        gp.AddMessage("Congratulations! You identified suitable habitat!")

